Privacy Policy Statement — mosaik 2.3.1 documentation

# Privacy Policy Statement

With this statement we would like to inform you which data are stored at this site, when the data are stored and how the data are used. All data, without exception, collected during a visit to our web site are processed in accordance with the current German data protection acts. We have taken technical and organizational measures in order to protect your rights.

For further details, we refer to our privacy policy statement in German language which is authoritative.

Google Analytics

This website uses Google Analytics, a web analytics service provided by Google, Inc. (“Google”). Google Analytics uses cookies, which are text files placed on your computer, to help the website analyze how users use the site. The information generated by the cookie about your use of the website (including your IP address) will be transmitted to and stored by Google on servers in the United States.

In case of activation of the IP anonymization, Google will truncate/anonymize the last octet of the IP address for Member States of the European Union as well as for other parties to the Agreement on the European Economic Area. Only in exceptional cases, the full IP address is sent to and shortened by Google servers in the USA. On behalf of the website provider Google will use this information for the purpose of evaluating your use of the website, compiling reports on website activity for website operators and providing other services relating to website activity and internet usage to the website provider. Google will not associate your IP address with any other data held by Google. You may refuse the use of cookies by selecting the appropriate settings on your browser. However, please note that if you do this, you may not be able to use the full functionality of this website. Furthermore you can prevent Google’s collection and use of data (cookies and IP address) by downloading and installing the browser plug-in available under https://tools.google.com/dlpage/gaoptout?hl=en-GB.

You can refuse the use of Google Analytics by clicking on the following link. An opt-out cookie will be set on the computer, which prevents the future collection of your data when visiting this website: Disable Google Analytics

Further information concerning the terms and conditions of use and data privacy can be found at http://www.google.com/analytics/terms/gb.html or at https://www.google.de/intl/en_uk/policies/.

Please note that on this website, Google Analytics code is supplemented by “gat._anonymizeIp();” to ensure an anonymized collection of IP addresses (so called IP-masking).

Storage of Data

In order to monitor and evaluate performance and security, our web server temporarily registers the following data when you visit our website

- the name of the file being accessed,
- the IP address of the client,
- the date and time of the access,
- the amount of data transmitted,
- the retrieval status (file transmitted, file not found, etc.), and
- the type of the browser used.

The stored data are only used for statistical evaluation and not passed on to a third party in any way.

Links to Other Sites and Disclaimer of Liability

The links to pages not hosted by our web server are only provided for your information. We are not responsible for the content, availability, correctness or accuracy of the linked sites, nor for the services, links or advertisements provided therein. We accept no liability for illegal, incorrect or incomplete content on the linked sites nor, in particular, for damages arising from the use or non-use of the information provided. there.

If you have any questions about this statement, please do not hesitate to contact us.